//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/FootprintItems.cpp
//! @brief     Implements FootprintItem classes
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Device/FootprintItems.h"
#include "Device/Beam/FootprintGauss.h"
#include "Device/Beam/FootprintSquare.h"
#include "GUI/Support/XML/Serialize.h"

namespace {
namespace Tag {

const QString GaussianFootprint("GaussianFootprint");
const QString SquareFootprint("SquareFootprint");

} // namespace Tag
} // namespace

std::unique_ptr<IFootprintFactor> FootprintNoneItem::createFootprint() const
{
    return {};
}

FootprintGaussianItem::FootprintGaussianItem(double value)
{
    m_gaussianFootprintValue.init("Width ratio", "The ratio of beam and sample full widths", value,
                                  Unit::unitless, 3 /* decimals */, RealLimits::nonnegative(),
                                  "ratio");
}

void FootprintGaussianItem::serialize(Streamer& s)
{
    s.assertVersion(0);
    Serialize::rwProperty(s, Tag::GaussianFootprint, m_gaussianFootprintValue);
}

std::unique_ptr<IFootprintFactor> FootprintGaussianItem::createFootprint() const
{
    return std::make_unique<FootprintGauss>(m_gaussianFootprintValue);
}

FootprintSquareItem::FootprintSquareItem(double value)
{
    m_squareFootprintValue.init("Width ratio", "The ratio of beam and sample full widths", value,
                                Unit::unitless, 3 /* decimals */, RealLimits::nonnegative(),
                                "ratio");
}

void FootprintSquareItem::serialize(Streamer& s)
{
    s.assertVersion(0);
    Serialize::rwProperty(s, Tag::SquareFootprint, m_squareFootprintValue);
}

std::unique_ptr<IFootprintFactor> FootprintSquareItem::createFootprint() const
{
    return std::make_unique<FootprintSquare>(m_squareFootprintValue);
}
