//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/CompoundItem.h
//! @brief     Defines class CompoundItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_COMPOUNDITEM_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_COMPOUNDITEM_H

#include "GUI/Model/CatSample/ItemWithParticlesCatalog.h"
#include "GUI/Model/Sample/ItemWithParticles.h"
#include "Sample/Particle/Compound.h"
#include <memory>

class MaterialModel;

class CompoundItem : public ItemWithParticles {
public:
    CompoundItem(const MaterialModel* materials);
    void serialize(Streamer& s) override;
    void writeTo(QXmlStreamWriter* w) const override;
    void readFrom(QXmlStreamReader* r) override;

    std::unique_ptr<Compound> createCompound() const;

    QVector<ItemWithParticles*> particles() const;
    SelectionProperty<ItemWithParticlesCatalog>& addParticleItem(ItemWithParticles* particle);
    void removeParticleItem(ItemWithParticles* particle);

    QVector<ItemWithParticles*> containedItemsWithParticles() const override;

private:
    std::vector<SelectionProperty<ItemWithParticlesCatalog>> m_particleSelections;
    const MaterialModel* m_materialModel;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_COMPOUNDITEM_H
