//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Contrib/RoughMultiLayerContribution.h
//! @brief     Defines class RoughMultiLayerContribution.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_SIM_CONTRIB_ROUGHMULTILAYERCONTRIBUTION_H
#define BORNAGAIN_SIM_CONTRIB_ROUGHMULTILAYERCONTRIBUTION_H

#include <heinz/Complex.h>

class ReSample;
class DiffuseElement;

//! Computes the diffuse reflection from the rough interfaces of a sample.
//! Used by DWBAComputation.

class RoughMultiLayerContribution final {
public:
    RoughMultiLayerContribution(const ReSample& re_sample);

    void compute(DiffuseElement& ele) const;

private:
    const ReSample& m_re_sample;

    complex_t get_refractive_term(size_t i_layer, double wavelength) const;
    complex_t get_sum8terms(size_t i_layer, const DiffuseElement& ele) const;
};

#endif // BORNAGAIN_SIM_CONTRIB_ROUGHMULTILAYERCONTRIBUTION_H
